---
title: <span class="badge builder"></span> NotificationTemplate
---
# <span class="badge builder"></span> NotificationTemplate

## Constructor

```python
NotificationTemplate()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.NotificationTemplate
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> provenance

```python
def provenance(provenance: alerting.Provenance) -> typing.Self
```

### <span class="badge object-method"></span> template

```python
def template(template: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [NotificationTemplate](./object-NotificationTemplate.md)
